@@ -11,13 +11,15 @@ characters.
 from collections.abc import Callable
 from textwrap import TextWrapper
 from threading import RLock
-from typing import List, Generic, _GenericAlias  # noqa
+from typing import List, Generic, _GenericAlias, _SpecialForm  # noqa
 
 try:
     from wcwidth import wcswidth
 except ImportError:
     wcswidth = len
 
+__all__ = ['get_origin', 'cached_property', 'WCTextWrapper', 'Literal']
+
 
 # region typing
 
@@ -41,6 +43,43 @@ def _get_args(tp):  # pylint: disable=C0103
     return ()
 
 
+try:
+    from typing import Literal
+except ImportError:  # Python 3.7
+
+    class _LiteralSpecialForm(_SpecialForm, _root=True):
+        def __repr__(self) -> str:
+            return f'compat.{self._name}'
+
+        def __getitem__(self, parameters):
+            if not isinstance(parameters, tuple):
+                parameters = (parameters,)
+            return _GenericAlias(self, parameters)
+
+    _LITERAL_DOCSTRING = """
+    Special typing form to define literal types (a.k.a. value types).
+
+    This form can be used to indicate to type checkers that the corresponding
+    variable or function parameter has a value equivalent to the provided
+    literal (or one of several literals):
+
+      def validate_simple(data: Any) -> Literal[True]:  # always returns True
+          ...
+
+      MODE = Literal['r', 'rb', 'w', 'wb']
+      def open_helper(file: str, mode: MODE) -> str:
+          ...
+
+      open_helper('/some/path', 'r')  # Passes type check
+      open_helper('/other/path', 'typo')  # Error in type checker
+
+    Literal[...] cannot be subclassed. At runtime, an arbitrary value
+    is allowed as type argument to Literal[...], but type checkers may
+    impose restrictions.
+    """
+    Literal = _LiteralSpecialForm('Literal', doc=_LITERAL_DOCSTRING)
+
+
 # endregion
 
 # region functools
@@ -96,93 +135,6 @@ class cached_property:  # pylint: disable=C0103,R0903
         return val
 
 
-# endregion
-
-# region Enum / Flag
-
-
-def missing_flag(cls, value):
-    """Based on Flag._missing_ from 3.10 and below, which was changed drastically in 3.11"""
-    original_value = value
-    if value < 0:
-        value = ~value
-    possible_member = create_pseudo_member(cls, value)
-    if original_value < 0:
-        possible_member = ~possible_member
-    return possible_member
-
-
-def decompose_flag(flag_cls, value: int, name: str = None):
-    """Based on enum._decompose from 3.10 and below, which was removed in 3.11"""
-    member_map = flag_cls._member_map_
-    if name is not None:
-        try:
-            return [member_map[name]], 0
-        except KeyError:
-            pass
-
-    not_covered = value
-    negative = value < 0
-    members = []
-    for member in member_map.values():
-        member_value = member._value_
-        if member_value and member_value & value == member_value:
-            members.append(member)
-            not_covered &= ~member_value
-
-    if not negative:
-        tmp = not_covered
-        while tmp:
-            flag_value = 2 ** (tmp.bit_length() - 1)  # 2 ** _high_bit(tmp)
-            try:
-                members.append(flag_cls._value2member_map_[flag_value])
-            except KeyError:
-                pass
-            else:
-                not_covered &= ~flag_value
-
-            tmp &= ~flag_value
-
-    if not members:
-        try:
-            members.append(flag_cls._value2member_map_[value])
-        except KeyError:
-            pass
-
-    members.sort(key=lambda m: m._value_, reverse=True)
-    if len(members) > 1 and members[0]._value_ == value:
-        # we have the breakdown, don't need the value member itself
-        members.pop(0)
-    members.sort()
-    return members, not_covered
-
-
-def create_pseudo_member(flag_cls, value: int):
-    """
-    Create a composite member iff value contains only members.
-
-    Based on enum.Flag._create_pseudo_member_ from 3.10 and below, which was removed in 3.11
-    """
-    try:
-        return flag_cls._value2member_map_[value]  # noqa
-    except KeyError:
-        pass
-
-    # verify all bits are accounted for
-    _, extra_flags = decompose_flag(flag_cls, value)
-    if extra_flags:
-        raise ValueError(f'{value!r} is not a valid {flag_cls.__qualname__}')
-    # construct a singleton enum pseudo-member
-    if issubclass(flag_cls, int):
-        pseudo_member = int.__new__(flag_cls)
-    else:
-        pseudo_member = object.__new__(flag_cls)
-    pseudo_member._name_ = None
-    pseudo_member._value_ = value
-    # use setdefault in case another thread already created a composite with this value
-    return flag_cls._value2member_map_.setdefault(value, pseudo_member)  # noqa
-
-
 # endregion
 
 
