@@ -14,7 +14,7 @@ from ..context import ctx, ParseState
 from ..exceptions import ParameterDefinitionError, BadArgument, CommandDefinitionError, ParamUsageError
 from ..inputs import normalize_input_type
 from ..nargs import Nargs, NargsValue
-from ..typing import Bool, T_co, ChoicesType, InputTypeFunc, CommandCls, CommandObj, OptStr
+from ..typing import Bool, T_co, ChoicesType, InputTypeFunc, CommandCls, CommandObj, OptStr, LeadingDash
 from ..utils import _NotSet
 from .base import BasicActionMixin, BaseOption, parameter_action
 from .option_strings import TriFlagOptionStrings
@@ -53,6 +53,11 @@ class Option(BasicActionMixin, BaseOption[T_co]):
       will not be checked.  If multiple env variable names/keys were provided, then they will be checked in the order
       that they were provided.  When enabled, values from env variables take precedence over the default value.  When
       enabled and the Parameter is required, then either a CLI value or an env var value must be provided.
+    :param allow_leading_dash: Whether string values may begin with a dash (``-``).  By default, if a value begins with
+      a dash, it is only accepted if it appears to be a negative numeric value.  Use ``True`` / ``always`` /
+      ``AllowLeadingDash.ALWAYS`` to allow any value that begins with a dash (as long as it is not an option string for
+      an Option/Flag/etc).  To reject all values beginning with a dash, including numbers, use ``False`` / ``never`` /
+      ``AllowLeadingDash.NEVER``.
     :param kwargs: Additional keyword arguments to pass to :class:`.BaseOption`.
     """
 
@@ -68,18 +73,24 @@ class Option(BasicActionMixin, BaseOption[T_co]):
         type: InputTypeFunc = None,  # noqa
         choices: ChoicesType = None,
         env_var: Union[str, Sequence[str]] = None,
+        allow_leading_dash: LeadingDash = None,
         **kwargs,
     ):
         if nargs is not None:
             self.nargs = Nargs(nargs)
         if 0 in self.nargs:
-            raise ParameterDefinitionError(f'Invalid nargs={self.nargs} - use Flag or Counter for Options with 0 args')
+            details = 'use Flag or Counter for Options with 0 args'
+            if isinstance(nargs, range) and nargs.start == 0 and nargs.step != nargs.stop:
+                suffix = f', {nargs.step}' if nargs.step != 1 else ''
+                details = f'try using range({nargs.step}, {nargs.stop}{suffix}) instead, or {details}'
+            raise ParameterDefinitionError(f'Invalid nargs={nargs!r} - {details}')
         if action is _NotSet:
             action = 'store' if self.nargs == 1 else 'append'
         elif action == 'store' and self.nargs != 1:
             raise ParameterDefinitionError(f'Invalid nargs={self.nargs} for action={action!r}')
         super().__init__(*option_strs, action=action, default=default, required=required, **kwargs)
         self.type = normalize_input_type(type, choices)
+        self._validate_nargs_and_allow_leading_dash(allow_leading_dash)
         if env_var:
             self.env_var = env_var
 
@@ -92,9 +103,6 @@ class Option(BasicActionMixin, BaseOption[T_co]):
                 yield from env_var
 
 
-# TODO: 1/2 flag, 1/2 option, like Counter, but for any value
-
-
 class _Flag(BaseOption[T_co], ABC):
     nargs = Nargs(0)
     _use_opt_str: bool = False
@@ -318,6 +326,7 @@ class ActionFlag(Flag, repr_attrs=('order', 'before_main')):
     def __lt__(self, other: ActionFlag) -> bool:
         if not isinstance(other, ActionFlag):
             return NotImplemented
+        # noinspection PyTypeChecker
         return (not self.before_main, self.order, self.name) < (not other.before_main, other.order, other.name)
 
     def __call__(self, func: Callable) -> ActionFlag:
